@@ -1006,6 +1006,8 @@ static char top_err[] = "Cannot identify meter top";
 		wmeasure = m1 * BASE_LEN / m2;
 		s->u.meter.expdur = 1;
 	}
+	if (wmeasure > BASE_LEN * 16 || wmeasure < 0)
+		return "Too big meter value";
 	s->u.meter.wmeasure = wmeasure;
 	s->u.meter.nmeter = nm;
 
@@ -1804,16 +1806,9 @@ static char *parse_len(char *p,
 	len = dur_u;
 	if (isdigit((unsigned char) *p)) {
 		len *= strtol(p, &q, 10);
-		if (len <= 0 || len > 10000) {
-			syntax("Bad length", p);
-			len = dur_u;
-		}
 		p = q;
 	}
-	if (*p != '/') {
-		*p_len = len;
-		return p;
-	}
+    if (*p == '/') {
 	if (isdigit((unsigned char) p[1])) {
 		fac = strtol(p + 1, &q, 10);
 		p = q;
@@ -1833,6 +1828,11 @@ static char *parse_len(char *p,
 		syntax("Bad length divisor", p - 1);
 		len = dur_u;
 	}
+    }
+	if (len <= 0 || len > 10000) {
+		syntax("Bad length", p);
+		len = dur_u;
+	}
 	*p_len = len;
 	return p;
 }
@@ -2360,11 +2360,16 @@ static char *parse_note(char *p,
 		p++;
 		if (isdigit((unsigned char) *p)		/* number of points */
 		 || *p == '-') {			/* accept negative offset... */
-			s->u.note.notes[0].shhd = strtol(p, &q, 10);
+			len = strtol(p, &q, 10);
+			if (len < -100 || len > 100) {
+				syntax("Bad width of y (space)", p);
+				len = 10;
+			}
 			p = q;
 		} else {
-			s->u.note.notes[0].shhd = 10;	// default
+			len = 10;			// default
 		}
+		s->u.note.notes[0].shhd = len;
 		goto add_deco;
 	case 'x':			/* invisible rest */
 		s->flags |= ABC_F_INVIS;
