@@ -66,6 +66,7 @@ static struct format {
 	{"decoerr", &cfmt.decoerr, FORMAT_B, 0},
 	{"dynalign", &cfmt.dynalign, FORMAT_B, 0},
 	{"footer", &cfmt.footer, FORMAT_S, 0},
+	{"footer2", &cfmt.footer2, FORMAT_S, 0},
 	{"footerfont", &cfmt.font_tb[FOOTERFONT], FORMAT_F, 0},
 	{"flatbeams", &cfmt.flatbeams, FORMAT_B, 0},
 	{"flatbeamgracing", &cfmt.flatbeamgracing, FORMAT_B, 0},
@@ -76,6 +77,7 @@ static struct format {
 	{"gracespace", &cfmt.gracespace, FORMAT_I, 5},
 	{"gutter", &cfmt.gutter, FORMAT_U, 0},
 	{"header", &cfmt.header, FORMAT_S, 0},
+	{"header2", &cfmt.header2, FORMAT_S, 0},
 	{"headerfont", &cfmt.font_tb[HEADERFONT], FORMAT_F, 0},
 	{"historyfont", &cfmt.font_tb[HISTORYFONT], FORMAT_F, 0},
 	{"hyphencont", &cfmt.hyphencont, FORMAT_B, 0},
